@@ -2,9 +2,12 @@
 from .version import __version__
 
 # Main
-from .ecs3.main.pyrogen_app import PyrogenApp
+from .ecs3.main.pyrogen_app import Pyrogen
 from .ecs3.main.entity      import Entity
 from .ecs3.main.scene       import Scene
 
 # Components
-from .ecs3.components.gfx import GfxSprite, GfxBox
+from .ecs3.components.gfx    import GfxSprite, GfxBox
+from .ecs3.components.script import Script
+
+
